==> kubernetes-model-core-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/NodeDaemonEndpointsFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NodeDaemonEndpointsFluent<A extends NodeDaemonEndpointsFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildKubeletEndpoint instead.
   * @return The buildable object.
   */
  @Deprecated
  public DaemonEndpoint getKubeletEndpoint();
  public DaemonEndpoint buildKubeletEndpoint();
  public A withKubeletEndpoint(DaemonEndpoint kubeletEndpoint);
  public Boolean hasKubeletEndpoint();
  public A withNewKubeletEndpoint(Integer port);
  public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> withNewKubeletEndpoint();
  public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> withNewKubeletEndpointLike(DaemonEndpoint item);
  public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editKubeletEndpoint();
  public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editOrNewKubeletEndpoint();
  public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editOrNewKubeletEndpointLike(DaemonEndpoint item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface KubeletEndpointNested<N> extends Nested<N>,DaemonEndpointFluent<NodeDaemonEndpointsFluent.KubeletEndpointNested<N>>{
    public N and();
    public N endKubeletEndpoint();
    
  }
  
}

==> kubernetes-model-core-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/NodeDaemonEndpointsFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NodeDaemonEndpointsFluent<A extends NodeDaemonEndpointsFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildKubeletEndpoint instead.
   * @return The buildable object.
   */
  @Deprecated
  public DaemonEndpoint getKubeletEndpoint();
  public DaemonEndpoint buildKubeletEndpoint();
  public A withKubeletEndpoint(DaemonEndpoint kubeletEndpoint);
  public Boolean hasKubeletEndpoint();
  public A withNewKubeletEndpoint(Integer port);
  public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> withNewKubeletEndpoint();
  public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> withNewKubeletEndpointLike(DaemonEndpoint item);
  public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editKubeletEndpoint();
  public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editOrNewKubeletEndpoint();
  public NodeDaemonEndpointsFluent.KubeletEndpointNested<A> editOrNewKubeletEndpointLike(DaemonEndpoint item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface KubeletEndpointNested<N> extends Nested<N>,DaemonEndpointFluent<NodeDaemonEndpointsFluent.KubeletEndpointNested<N>>{
    public N and();
    public N endKubeletEndpoint();
    
  }
  
}
